@@ -8,8 +8,7 @@ import os
 from Excelutilities import importing_data_helpers 
 from Excelutilities import index_helpers
 import pkg_resources
-first_and_last_row_index = index_helpers.first_and_last_row_index
-is_from_single_col = index_helpers.is_from_single_col
+ 
 
 def export_data():
     product_id_types = {"ASIN":1,
@@ -45,14 +44,14 @@ def export_data():
     sg.popup_ok(f"Please select the product keys for the items you wish to upload")
     current_address = xw.apps.active.books.active.selection.address
 
-    while is_from_single_col(current_address) == False:
+    while index_helpers.is_from_single_col(current_address) == False:
         user_output = sg.popup_yes_no("Please select from a single column block.\nClick Yes to continue and reselect, or No to terminate the program")
         if user_output == "No":
             sys.exit()
         else:
             current_address = xw.apps.active.books.active.selection.address
     
-    first_and_lasts = [first_and_last_row_index(block) for block in current_address.split(",")]
+    first_and_lasts = [index_helpers.first_and_last_row_index(block) for block in current_address.split(",")]
 
     for first_row_index, last_row_index in first_and_lasts:
         
